package com.ruoyi.postCheck.service;

import java.util.List;
import com.ruoyi.postCheck.domain.PostAssessmentRating;
import com.baomidou.mybatisplus.extension.service.IService;

/**
 * 考核评比Service接口
 *
 * @author csg
 * @date 2023-12-21
 */
public interface IPostAssessmentRatingService extends IService<PostAssessmentRating>
{
    /**
     * 查询考核评比
     *
     * @param id 考核评比主键
     * @return 考核评比
     */
    public PostAssessmentRating selectPostAssessmentRatingById(Long id);

    /**
     * 查询考核评比列表
     *
     * @param postAssessmentRating 考核评比
     * @return 考核评比集合
     */
    public List<PostAssessmentRating> selectPostAssessmentRatingList(PostAssessmentRating postAssessmentRating);

    /**
     * 新增考核评比
     *
     * @param postAssessmentRating 考核评比
     * @return 结果
     */
    public int insertPostAssessmentRating(PostAssessmentRating postAssessmentRating);

    /**
     * 修改考核评比
     *
     * @param postAssessmentRating 考核评比
     * @return 结果
     */
    public int updatePostAssessmentRating(PostAssessmentRating postAssessmentRating);

    /**
     * 批量删除考核评比
     *
     * @param ids 需要删除的考核评比主键集合
     * @return 结果
     */
    public int deletePostAssessmentRatingByIds(Long[] ids);

    /**
     * 删除考核评比信息
     *
     * @param id 考核评比主键
     * @return 结果
     */
    public int deletePostAssessmentRatingById(Long id);
}
